@@ -79,27 +79,32 @@
 #'                devel = TRUE)
 #' }
 #' @export
-nfl_team_tiers <- function(data,
-                           title = "NFL Team Tiers, 2021 as of Week 4",
-                           subtitle = "created with the #nflplotR Tiermaker",
-                           caption = NULL,
-                           tier_desc = c("1" = "Super Bowl",
-                                         "2" = "Very Good",
-                                         "3" = "Medium",
-                                         "4" = "Bad",
-                                         "5" = "What are they doing?",
-                                         "6" = "",
-                                         "7" = ""),
-                           presort = FALSE,
-                           alpha = 0.8,
-                           width = 0.075,
-                           no_line_below_tier = NULL,
-                           devel = FALSE){
-
+nfl_team_tiers <- function(
+  data,
+  title = "NFL Team Tiers, 2021 as of Week 4",
+  subtitle = "created with the #nflplotR Tiermaker",
+  caption = NULL,
+  tier_desc = c(
+    "1" = "Super Bowl",
+    "2" = "Very Good",
+    "3" = "Medium",
+    "4" = "Bad",
+    "5" = "What are they doing?",
+    "6" = "",
+    "7" = ""
+  ),
+  presort = FALSE,
+  alpha = 0.8,
+  width = 0.075,
+  no_line_below_tier = NULL,
+  devel = FALSE
+) {
   required_vars <- c("tier_no", "team_abbr")
 
-  if (!all(required_vars %in% names(data))){
-    cli::cli_abort("The data frame {.var data} has to include the variables {.var {required_vars}}!")
+  if (!all(required_vars %in% names(data))) {
+    cli::cli_abort(
+      "The data frame {.var data} has to include the variables {.var {required_vars}}!"
+    )
   }
 
   bg <- "#1e1e1e"
@@ -109,23 +114,37 @@ nfl_team_tiers <- function(data,
   tierlines <- tiers[!tiers %in% no_line_below_tier] + 0.5
   tierlines <- c(min(tiers) - 0.5, tierlines)
 
-  if (isTRUE(presort)){
+  if (isTRUE(presort)) {
     data <- data.table::as.data.table(data)[order(tier_no, team_abbr)]
     data[, tier_rank := 1:.N, by = "tier_no"]
   }
 
-  if (!"tier_rank" %in% names(data)){
+  if (!"tier_rank" %in% names(data)) {
     data <- data.table::as.data.table(data)
     data[, tier_rank := 1:.N, by = "tier_no"]
   }
 
-  data$team_abbr <- nflreadr::clean_team_abbrs(as.character(data$team_abbr), keep_non_matches = FALSE)
+  data$team_abbr <- nflreadr::clean_team_abbrs(
+    as.character(data$team_abbr),
+    keep_non_matches = FALSE
+  )
 
-  p <- ggplot2::ggplot(data, ggplot2::aes(y = .data$tier_no, x = .data$tier_rank)) +
+  p <- ggplot2::ggplot(
+    data,
+    ggplot2::aes(y = .data$tier_no, x = .data$tier_rank)
+  ) +
     ggplot2::geom_hline(yintercept = tierlines, color = lines)
 
-  if(isFALSE(devel)) p <- p + nflplotR::geom_nfl_logos(ggplot2::aes(team_abbr = .data$team_abbr), width = width, alpha = alpha)
-  if(isTRUE(devel))p <- p + ggplot2::geom_text(ggplot2::aes(label = .data$team_abbr), color = "white")
+  if (isFALSE(devel))
+    p <- p +
+      nflplotR::geom_nfl_logos(
+        ggplot2::aes(team_abbr = .data$team_abbr),
+        width = width,
+        alpha = alpha
+      )
+  if (isTRUE(devel))
+    p <- p +
+      ggplot2::geom_text(ggplot2::aes(label = .data$team_abbr), color = "white")
 
   p <- p +
     ggplot2::scale_y_continuous(
@@ -143,7 +162,11 @@ nfl_team_tiers <- function(data,
       plot.caption = ggplot2::element_text(color = "#8e8e93", hjust = 1),
       plot.title.position = "plot",
       axis.text.x = ggplot2::element_blank(),
-      axis.text.y = ggplot2::element_text(color = "white", face = "bold", size = ggplot2::rel(1.1)),
+      axis.text.y = ggplot2::element_text(
+        color = "white",
+        face = "bold",
+        size = ggplot2::rel(1.1)
+      ),
       axis.title = ggplot2::element_blank(),
       panel.grid = ggplot2::element_blank(),
       plot.background = ggplot2::element_rect(fill = bg, color = bg),
@@ -153,4 +176,3 @@ nfl_team_tiers <- function(data,
 
   p
 }
-
